@@ -1,12 +1,16 @@
 """Defines the main ksim API."""
 
-__version__ = "0.0.15"
+__version__ = "0.2.6"
 
+from .actions import *
 from .actuators import *
 from .commands import *
 from .curriculum import *
+from .dataset import *
+from .debugging import *
 from .engine import *
 from .events import *
+from .noise import *
 from .observation import *
 from .randomization import *
 from .resets import *
@@ -15,3 +19,4 @@ from .task import *
 from .terminations import *
 from .types import *
 from .utils import *
+from .vis import *
